==> rktSNS_1.070202.tgz: rktSNS/webapp/modules/admin/sponsor/sponsor.php <==
<?php
/* ========================================================================
 - [modules/admin/sponsor/sponsor.php]
 -      スポンサーバナー編集
 -      Copyright (c) 2006 Yujiro Takahashi
 - ライセンス:
 -      This program is free software; you can redistribute it and/or
 -      modify it under the terms of the GNU General Public License
 -      as published by the Free Software Foundation; either version 2
 -      of the License, or (at your option) any later version.
 -
 -      This program is distributed in the hope that it will be useful,
 -      but WITHOUT ANY WARRANTY; without even the implied warranty of
 -      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 -      GNU General Public License for more details.
 -
 -      You should have received a copy of the GNU General Public License
 -      along with this program; if not, write to the Free Software
 -      Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 - 問い合わせ先：
 -      yujiro@rakuto.net
 -      http://rakuto.net/rktSNS/
 - 更新履歴：
 -      [2006/08/02] 作成
 - ======================================================================== */

/* =-=- モジュール等の読み込み -=-= */
require_once LIB_DIR.'rkt_manip.php';
require_once WEBAPP_LIB_DIR.'wap_admin.php';

/**
 * WebApplication実装クラス
 *
 * @author 高橋 裕志郎 <yujiro@rakuto.net>
 * @package webapp
 * @access public
 * @version 1.0
 */
class webapp extends WAP_admin
{
    /**
     * スポンサーID
     * @var integer
     */
    var $id = null;

    /**
     * データ操作オブジェクト
     * @var object
     */
    var $objmnp = null;

    /**
     * 実行処理
     *
     * @access public
     * @return void
     **/
    function execute()
    {
        RKT_auth::Authenticate(array(WAP_ACC_ADMIN));

        $this->setTemplateFile('admin/sponsor/sponsor.tpl');        
        $this->addJavas('admin.js');

        // URL引数の取得
        $this->setSafety('id');
        $this->Assign('id', $this->id);

        // データ操作クラスの生成
        $this->objmnp = new RKT_manip($this->objdb, DB_PREFIX.'sys_sponsor');
        $result = $this->do_query();
        if ($result == RKT_MANIP_COMPLETE){
            header('Location: '.HTTP_ACTION.'admin/sponsor/list/complete/');
            exit();
        }
        if ($this->delete_sponsor()){
            header('Location: '.HTTP_ACTION.'admin/sponsor/list/complete/');
            exit();
        }
    }

    /**
     * データ操作設定・実行
     *
     * @access private
     * @return integer  データ操作結果
     */
    function do_query()
    {
        // 新規登録以外の処理
        if (!empty($this->id)){
            $this->objmnp->setCurID($this->id);
        } else {
            $this->objmnp->setValue('avail', AVAIL_ENABLE);
        }
        
        // 更新しない項目名
        $skip = array(
            'avail',
            'html'
        );
        $this->objmnp->catchInput($skip);
        
        $tags = ALLOWABLE_TAGS;
        $tags .= '<div><script><iframe>';
        /* HTML項目を文字列なら全て許可 */
        $validate_info = array(
            'type'=> 'string',
            'required'=> true,
            'tags'=> $tags
        );
        $this->objmnp->setInput('html', $validate_info);

        return $this->objmnp->doManip($this);
    }

    /**
     * スポンサー情報の削除
     *
     * @access private
     * @return integer  データ操作結果
     */
    function delete_sponsor()
    {
        if (empty($_POST['delete'])){
            return false;
        }

        $sql =
            'DELETE FROM '.
                DB_PREFIX.'sys_sponsor '.
            'WHERE '.
                'id ='.$this->id;
        return $this->objdb->exec($sql);
    }
} // webapp
?>

==> rktSNS_1.070819.tgz: rktSNS/webapp/modules/admin/sponsor/sponsor.php <==
<?php
/* ========================================================================
 - [modules/admin/sponsor/sponsor.php]
 -      スポンサーバナー編集
 -      Copyright (c) 2006 Yujiro Takahashi
 - ライセンス:
 -      This program is free software; you can redistribute it and/or
 -      modify it under the terms of the GNU General Public License
 -      as published by the Free Software Foundation; either version 2
 -      of the License, or (at your option) any later version.
 -
 -      This program is distributed in the hope that it will be useful,
 -      but WITHOUT ANY WARRANTY; without even the implied warranty of
 -      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 -      GNU General Public License for more details.
 -
 -      You should have received a copy of the GNU General Public License
 -      along with this program; if not, write to the Free Software
 -      Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 - 問い合わせ先：
 -      yujiro@rakuto.net
 -      http://rakuto.net/rktSNS/
 - 更新履歴：
 -      [2006/08/02] 作成
 - ======================================================================== */

/* =-=- モジュール等の読み込み -=-= */
require_once LIB_DIR.'rkt_manip.php';
require_once WEBAPP_LIB_DIR.'wap_admin.php';

/**
 * WebApplication実装クラス
 *
 * @author 高橋 裕志郎 <yujiro@rakuto.net>
 * @package webapp
 * @access public
 * @version 1.0
 */
class webapp extends WAP_admin
{
    /**
     * スポンサーID
     * @var integer
     */
    var $id = null;

    /**
     * データ操作オブジェクト
     * @var object
     */
    var $objmnp = null;

    /**
     * 実行処理
     *
     * @access public
     * @return void
     **/
    function execute()
    {
        RKT_auth::Authenticate(array(WAP_ACC_ADMIN));

        $this->setTemplateFile('admin/sponsor/sponsor.tpl');        
        $this->addJavas('admin.js');

        // URL引数の取得
        $this->setSafety('id');
        $this->Assign('id', $this->id);

        // データ操作クラスの生成
        $this->objmnp = new RKT_manip($this->objdb, DB_PREFIX.'sys_sponsor');
        $result = $this->do_query();
        if ($result == RKT_MANIP_COMPLETE){
            header('Location: '.HTTP_ACTION.'admin/sponsor/list/complete/');
            exit();
        }
        if ($this->delete_sponsor()){
            header('Location: '.HTTP_ACTION.'admin/sponsor/list/complete/');
            exit();
        }
    }

    /**
     * データ操作設定・実行
     *
     * @access private
     * @return integer  データ操作結果
     */
    function do_query()
    {
        // 新規登録以外の処理
        if (!empty($this->id)){
            $this->objmnp->setCurID($this->id);
        } else {
            $this->objmnp->setValue('avail', AVAIL_ENABLE);
        }
        
        // 更新しない項目名
        $skip = array(
            'avail',
            'html'
        );
        $this->objmnp->catchInput($skip);
        
        /* 入力条件を指定 */
        $validate_info = array(
            'type'=>    'string',
            'option'=>  null,
            'required'=>true,
            'effect'=>  array('RKT_validate', 'strip_slashes'),
        );
        $this->objmnp->setInput('html', $validate_info);


        return $this->objmnp->doManip($this);
    }

    /**
     * スポンサー情報の削除
     *
     * @access private
     * @return integer  データ操作結果
     */
    function delete_sponsor()
    {
        if (empty($_POST['delete'])){
            return false;
        }

        $sql =
            'DELETE FROM '.
                DB_PREFIX.'sys_sponsor '.
            'WHERE '.
                'id ='.$this->id;
        return $this->objdb->exec($sql);
    }
} // webapp
?>
